/***********************************************************************
*
* Copyright (c) 2021-2022 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

class MainWindow : public QWidget
{
 public:
   MainWindow();

 private:
   QCompleter *strCompleter;
};

MainWindow::MainWindow()
{
   setMinimumSize(500, 150);

   QStringList list = {"Custard", "Carrot Cake", "Cheesecake", "Cinnamon Rolls",
         "Chocolate Cake", "Chocolate Chip Cookies", "Cherry Pie", "Cannoli", "Coffee Cake",
         "Coconut Cream Pie", "Churros", "Cranberry Muffins", "Cream Puffs" };

   std::sort(list.begin(), list.end());

   strCompleter = new QCompleter(list, this);
   strCompleter->setCaseSensitivity(Qt::CaseInsensitive);

   QLabel *label_1 = new QLabel("Dessert Name:");

   QLineEdit *text_1 = new QLineEdit();
   text_1->setText("");
   text_1->setPlaceholderText("Enter a dessert name starting with C...");
   text_1->setCompleter(strCompleter);

   QPushButton *pb_1 = new QPushButton();
   pb_1->setText("Close");

   QHBoxLayout *layout1 = new QHBoxLayout();
   layout1->addWidget(label_1);
   layout1->addWidget(text_1);

   QHBoxLayout *layout2 = new QHBoxLayout();
   layout2->addStretch();
   layout2->addWidget(pb_1);
   layout2->addStretch();

   QVBoxLayout *layoutMain = new QVBoxLayout(this);
   layoutMain->setContentsMargins(75, 35, 75, 15);

   layoutMain->addLayout(layout1);
   layoutMain->addStretch();
   layoutMain->addLayout(layout2);

   connect(pb_1, &QPushButton::clicked, this, &QWidget::close);
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}